*==============================================================================
* Program:				NewObject
* Purpose:				Create an object from a specified class
* Author:				Doug Hennig
* Copyright:			(c) 1997 Stonefield Systems Group Inc.
* Last revision:		03/20/98
* Parameters:			tcClass   - the name of the class to instantiate
*						tcLibrary - the name of the class library containing
*							the class
*						tcInApp   - the name of the application the class is in
*						tuParm1   - an optional parameter to pass to the new
*							object's Init method
*						tuParm2   - an optional parameter to pass to the new
*							object's Init method
*						tuParm3   - an optional parameter to pass to the new
*							object's Init method
*						tuParm4   - an optional parameter to pass to the new
*							object's Init method
* Returns:				the return value from CREATEOBJECT() (usually an object
*							reference but it could also be .F. if the object
*							failed to instantiate)
* Environment in:		if tcLibrary isn't specified, it must already be opened
*							with SET CLASSLIB (for a VCX) or SET LIBRARY or SET
*							PROCEDURE (for a PRG)
* Environment out:		the object may have been instantiated
*==============================================================================

lparameters tcClass, ;
	tcLibrary, ;
	tcInApp, ;
	tuParm1, ;
	tuParm2, ;
	tuParm3, ;
	tuParm4
local lcLibrary, ;
	lcInApp, ;
	loObject

* If the class library is specified, SET CLASSLIB to it if necessary.

do case
	case type('tcLibrary') <> 'C' or empty(tcLibrary) or ;
		upper(tcLibrary) $ upper(set('CLASSLIB'))
		lcLibrary = ''
	case file(tcLibrary)
		lcLibrary = upper(tcLibrary)
	otherwise
		lcLibrary = upper(locfile(tcLibrary, ;
			'Visual Class Library (*.vcx):VCX;Program (*.prg):PRG', tcLibrary))
endcase
if not empty(lcLibrary)
	lcInApp = iif(type('tcInApp') = 'C' and not empty(tcInApp), 'in tcInApp', ;
		'')
	set classlib to (lcLibrary) &lcInApp additive
endif not empty(lcLibrary)

* Create the object.

do case
	case pcount() < 4
		loObject = createobject(tcClass)
	case pcount() = 4
		loObject = createobject(tcClass, @tuParm1)
	case pcount() = 5
		loObject = createobject(tcClass, @tuParm1, @tuParm2)
	case pcount() = 6
		loObject = createobject(tcClass, @tuParm1, @tuParm2, @tuParm3)
	case pcount() = 7
		loObject = createobject(tcClass, @tuParm1, @tuParm2, @tuParm3, ;
			@tuParm4)
endcase

* Release the library if we opened it (and it's still open) and return a
* reference to the object we created.

if not empty(lcLibrary) and lcLibrary $ upper(set('CLASSLIB'))
	release classlib (lcLibrary)
endif not empty(lcLibrary) ...
return loObject
